@@ -5,7 +5,7 @@ __all__ = [
     "Devices",
 ]
 
-from typing import List
+from collections import Sequence
 
 from . import (
     check,
@@ -20,15 +20,9 @@ from . import (
 class DevicesType(ObjectType):
     """Metaclass for `Devices`."""
 
-    def __iter__(cls):
-        return map(cls._object, cls._handler.read())
-
-    def read(cls):
-        return cls(cls)
-
-
-class DeviceNotFound(Exception):
-    """Device was not found."""
+    async def read(cls):
+        data = await cls._handler.read()
+        return cls(map(cls._object, data))
 
 
 class Devices(ObjectSet, metaclass=DevicesType):
@@ -37,8 +31,8 @@ class Devices(ObjectSet, metaclass=DevicesType):
 
 class DeviceType(ObjectType):
 
-    def read(cls, system_id):
-        data = cls._handler.read(system_id=system_id)
+    async def read(cls, system_id):
+        data = await cls._handler.read(system_id=system_id)
         return cls(data)
 
 
@@ -47,16 +41,16 @@ class Device(Object, metaclass=DeviceType):
 
     hostname = ObjectField.Checked(
         "hostname", check(str), check(str))
-    ip_addresses = ObjectField.Checked(
-        "ip_addresses", check(List[str]), readonly=True)
+    ip_addresses = ObjectField.Checked(  # List[str]
+        "ip_addresses", check(Sequence), readonly=True)
 
     # owner
     # resource_uri
 
     system_id = ObjectField.Checked(
         "system_id", check(str), readonly=True)
-    tags = ObjectField.Checked(
-        "tag_names", check(List[str]), readonly=True)
+    tags = ObjectField.Checked(  # List[str]
+        "tag_names", check(Sequence), readonly=True)
     zone = zones.ZoneField(
         "zone", readonly=True)
 
